Package: ggPMX
Title: 'ggplot2' Based Tool to Facilitate Diagnostic Plots for NLME
        Models
Description: At Novartis, we aimed at standardizing the set of diagnostic plots used for modeling
  activities in order to reduce the overall effort required for generating such plots.
  For this, we developed a guidance that proposes an adequate set of diagnostics and a toolbox,
  called 'ggPMX' to execute them. 'ggPMX' is a toolbox that can generate all diagnostic plots at a quality sufficient
  for publication and submissions using few lines of code. This package focuses on plots recommended by ISoP
  <doi:10.1002/psp4.12161>. While not required, you can get/install the 'R' 'lixoftConnectors'
    package in the 'Monolix' installation, as described at the following url
    <https://monolixsuite.slp-software.com/r-functions/2024R1/installation-and-initialization>.
    When 'lixoftConnectors' is available, 'R' can use 'Monolix' directly to create the required
    Chart Data instead of exporting it from the 'Monolix' gui.
Version: 1.3.2
Authors@R: c(
              person("Amine", "Gassem", email="contact@ag-study.com", role=c("aut")),
              person("Bruno", "Bieth", email="biethb@hotmail.com", role="aut"),
              person("Irina", "Baltcheva", email="irina.baltcheva@gmail.com", role="aut"),
              person("Thomas", "Dumortier", email=" thomas.dumortier@novartis.com", role="aut"),
              person("Christian", "Bartels", email="christian.bartels@novartis.com", role="aut"),
              person("Souvik", "Bhattacharya", email="souvik.bhattacharya@novartis.com", role="aut"),
              person("Inga", "Ludwig", email="inga.ludwig@novartis.com", role="aut"),
              person("Ines", "Paule", email="ines.paule@novartis.com", role="aut"),
              person("Didier", "Renard", email="didier.renard@novartis.com", role="aut"),
	      person("Matthew","Fidler", role = c("aut"), email = "matt.fidler@novartis.com", comment=c(ORCID="0000-0001-8538-6691")),
	      person("Seid", "Hamzic", email = "se.hamzic@gmail.com",role ="aut"),
              person("Benjamin", "Guiastrennec", email = "guiastrennec@gmail.com",role ="ctb"),
              person("Kyle T", "Baron", email = "kyleb@metrumrg.com",role ="ctb", comment = c(ORCID = "0000-0001-7252-5656")),
              person("Qing Xi", "Ooi", email="ooi.qingxi@gmail.com", role="ctb"),
              person("Aleksandr","Pogodaev", role = c("aut", "cre"), email = "alex.pogodaev@novartis.com", comment=c(ORCID="0000-0002-1371-207X")),
              person("Danielle", "Navarro", role = c("aut"), email = "djnavarro@protonmail.com"),
              person("Ibtissem", "Rebai", email="ibtissem.rebai@certara.com", role="ctb"),
              person("Mahmoud", "Ali", email="mahmoud.ali@certara.com", role="ctb"),
              person("Novartis Pharma AG", role = c("cph"))
            )
URL: https://github.com/ggPMXdevelopment/ggPMX
BugReports: https://github.com/ggPMXdevelopment/ggPMX/issues
Depends: R (>= 3.5)
Imports: data.table, yaml, R6, gtable, ggplot2 (>= 3.4.0), ggforce,
        magrittr, stringr, assertthat, GGally, zoo, knitr, rmarkdown,
        tidyr, dplyr, purrr, readr, rlang, checkmate, scales
License: GPL-2
Suggests: testthat, xtable, vdiffr, rxode2, nlmixr2est, nlmixr2data,
        nlme, lixoftConnectors, xgxr, withr, lifecycle
VignetteBuilder: knitr
NeedsCompilation: no
RoxygenNote: 7.3.2
Encoding: UTF-8
Packaged: 2025-09-05 09:46:27 UTC; rstudio
Author: Amine Gassem [aut],
  Bruno Bieth [aut],
  Irina Baltcheva [aut],
  Thomas Dumortier [aut],
  Christian Bartels [aut],
  Souvik Bhattacharya [aut],
  Inga Ludwig [aut],
  Ines Paule [aut],
  Didier Renard [aut],
  Matthew Fidler [aut] (ORCID: <https://orcid.org/0000-0001-8538-6691>),
  Seid Hamzic [aut],
  Benjamin Guiastrennec [ctb],
  Kyle T Baron [ctb] (ORCID: <https://orcid.org/0000-0001-7252-5656>),
  Qing Xi Ooi [ctb],
  Aleksandr Pogodaev [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1371-207X>),
  Danielle Navarro [aut],
  Ibtissem Rebai [ctb],
  Mahmoud Ali [ctb],
  Novartis Pharma AG [cph]
Maintainer: Aleksandr Pogodaev <alex.pogodaev@novartis.com>
Repository: CRAN
Date/Publication: 2025-09-05 22:20:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:42:46 UTC; unix
