# Generated by roxygen2: do not edit by hand

S3method("[",pmx_gpar)
S3method(base::print,classIntervals)
S3method(plot_pmx,distrib)
S3method(plot_pmx,eta_cov)
S3method(plot_pmx,eta_pairs)
S3method(plot_pmx,individual)
S3method(plot_pmx,pmx_dens)
S3method(plot_pmx,pmx_gpar)
S3method(plot_pmx,pmx_param_history)
S3method(plot_pmx,pmx_qq)
S3method(plot_pmx,pmx_vpc)
S3method(plot_pmx,residual)
S3method(print,abbreviation)
S3method(print,configs)
S3method(print,pmxClass)
S3method(print,pmxConfig)
S3method(print,pmx_eta_matrix)
S3method(print,pmx_gpar)
export("%>%")
export(abbrev)
export(check_shrink)
export(getPmxOption)
export(get_abbrev)
export(get_cats)
export(get_conts)
export(get_covariates)
export(get_data)
export(get_occ)
export(get_plot)
export(get_plot_config)
export(get_strats)
export(is.pmx_gpar)
export(load_config)
export(load_source)
export(param_table)
export(parse_mlxtran)
export(pk_occ)
export(pk_pd)
export(plot_names)
export(plot_pmx)
export(plots)
export(pmx)
export(pmxOptions)
export(pmx_bloq)
export(pmx_comp_shrink)
export(pmx_config)
export(pmx_copy)
export(pmx_cov)
export(pmx_endpoint)
export(pmx_filter)
export(pmx_get_configs)
export(pmx_gpar)
export(pmx_mlx)
export(pmx_mlxtran)
export(pmx_nlmixr)
export(pmx_nm)
export(pmx_plot)
export(pmx_plot_abs_iwres_ipred)
export(pmx_plot_abs_iwres_time)
export(pmx_plot_cats)
export(pmx_plot_cwres_cpred)
export(pmx_plot_cwres_pred)
export(pmx_plot_cwres_qq)
export(pmx_plot_cwres_time)
export(pmx_plot_dv_ipred)
export(pmx_plot_dv_pred)
export(pmx_plot_eta_box)
export(pmx_plot_eta_cats)
export(pmx_plot_eta_conts)
export(pmx_plot_eta_hist)
export(pmx_plot_eta_matrix)
export(pmx_plot_eta_qq)
export(pmx_plot_individual)
export(pmx_plot_iwres_dens)
export(pmx_plot_iwres_ipred)
export(pmx_plot_iwres_qq)
export(pmx_plot_iwres_time)
export(pmx_plot_npd_epred)
export(pmx_plot_npd_pred)
export(pmx_plot_npd_qq)
export(pmx_plot_npd_time)
export(pmx_plot_npde_pred)
export(pmx_plot_npde_qq)
export(pmx_plot_npde_time)
export(pmx_plot_saem_convergence)
export(pmx_plot_vpc)
export(pmx_register_plot)
export(pmx_report)
export(pmx_report_template)
export(pmx_settings)
export(pmx_shrink)
export(pmx_sim)
export(pmx_theme)
export(pmx_update)
export(pmx_vpc)
export(pmx_vpc_bin)
export(pmx_vpc_ci)
export(pmx_vpc_obs)
export(pmx_vpc_pi)
export(pmx_vpc_rug)
export(read_extfile)
export(set_abbrev)
export(set_data)
export(set_plot)
export(theophylline)
import(data.table)
import(ggplot2)
importFrom(GGally,ggally_cor)
importFrom(GGally,ggally_densityDiag)
importFrom(GGally,ggally_text)
importFrom(GGally,ggmatrix)
importFrom(GGally,ggmatrix_gtable)
importFrom(R6,R6Class)
importFrom(assertthat,assert_that)
importFrom(ggforce,facet_wrap_paginate)
importFrom(grid,grid.draw)
importFrom(grid,grid.newpage)
importFrom(grid,pushViewport)
importFrom(grid,seekViewport)
importFrom(grid,upViewport)
importFrom(gtable,gtable_add_cols)
importFrom(gtable,gtable_add_rows)
importFrom(knitr,kable)
importFrom(knitr,knit_hooks)
importFrom(knitr,opts_chunk)
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
importFrom(rmarkdown,draft)
importFrom(rmarkdown,render)
importFrom(stats,cor)
importFrom(stats,formula)
importFrom(stats,setNames)
importFrom(stringr,str_trim)
importFrom(utils,assignInMyNamespace)
importFrom(utils,read.table)
importFrom(yaml,yaml.load_file)
importFrom(zoo,na.locf)
