---
date: "`r format(Sys.time(), '%d %B, %Y')`"
output: 
  pdf_document:
    toc: true
  word_document:
    toc: true
---

---
params:
  ctr: ""
  which_pages: ~
  title: ggPMX standing report
---

---
subtitle: `r params$ctr$save_dir `
title: `r params$title `
---


```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = FALSE,message=FALSE)

```


# Individual plots


```{r indiv,message=FALSE,fig.align="center",fig.height=10, fig.width=10}

 ctr %>% pmx_plot_individual(which_pages=params$which_pages,print=TRUE)
```


