---
date: "`r format(Sys.time(), '%d %B, %Y')`"
output: 
  pdf_document:
    toc: true
  word_document:
    toc: true
---

---
params:
  ctr: ""
  title: ""
---
---
subtitle: `r params$ctr$save_dir`
title: `r params$title `
---


```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = FALSE,message=FALSE)
cats <- ctr %>% get_cats

```


# Key model diagnostics

```{r npde_pred}
ctr %>% pmx_plot_npde_pred
```
